@@ -1,28 +1,32 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 # (c) Shrimadhav U K | gautamajay52
+# modified by reaitten/orsixtyone
 
 import logging
 import os
 import time
+import telegram.ext as tg
+from telegram import ParseMode, BotCommand
+
 from logging.handlers import RotatingFileHandler
 from collections import defaultdict
 from sys import exit
 
 import dotenv
 
-if os.path.exists("tgtlg.txt"):
-    with open("tgtlg.txt", "r+") as f_d:
+if os.path.exists("logs.txt"):
+    with open("logs.txt", "r+") as f_d:
         f_d.truncate(0)
 
 # the logging things
 logging.basicConfig(
-    level=logging.DEBUG,
+    level=logging.INFO,
     format="%(asctime)s - %(levelname)s - %(message)s [%(filename)s:%(lineno)d]",
     datefmt="%d-%b-%y %H:%M:%S",
     handlers=[
         RotatingFileHandler(
-            "tgtlg.txt", maxBytes=50000000, backupCount=10
+            "logs.txt", maxBytes=50000000, backupCount=10
         ),
         logging.StreamHandler(),
     ],
@@ -44,7 +48,7 @@ for imp in ["TG_BOT_TOKEN", "APP_ID", "API_HASH", "OWNER_ID", "AUTH_CHANNEL"]:
         if not value:
             raise KeyError
     except KeyError:
-        LOGGER.critical(f"Oh...{imp} is missing from config.env ... fill that")
+        LOGGER.critical(f"Oh...{imp}  is missing from config.env ... fill that")
         exit()
 
 # The Telegram API things
@@ -93,50 +97,80 @@ LEECH_COMMAND = os.environ.get("LEECH_COMMAND", "leech")
 LEECH_UNZIP_COMMAND = os.environ.get("LEECH_UNZIP_COMMAND", "extract")
 LEECH_ZIP_COMMAND = os.environ.get("LEECH_ZIP_COMMAND", "archive")
 GLEECH_COMMAND = os.environ.get("GLEECH_COMMAND", "gleech")
-GLEECH_UNZIP_COMMAND = os.environ.get("GLEECH_UNZIP_COMMAND", "gleechunzip")
-GLEECH_ZIP_COMMAND = os.environ.get("GLEECH_ZIP_COMMAND", "gleechzip")
+GLEECH_UNZIP_COMMAND = os.environ.get("GLEECH_UNZIP_COMMAND", "gextract")
+GLEECH_ZIP_COMMAND = os.environ.get("GLEECH_ZIP_COMMAND", "garchive")
+CLONE_COMMAND_G = os.environ.get("CLONE_COMMAND_G", "gclone")
+TELEGRAM_LEECH_COMMAND = os.environ.get("TELEGRAM_LEECH_COMMAND", "tleech")
+TELEGRAM_LEECH_UNZIP_COMMAND = os.environ.get("TELEGRAM_LEECH_UNZIP_COMMAND", "textract")
 YTDL_COMMAND = os.environ.get("YTDL_COMMAND", "ytdl")
 GYTDL_COMMAND = os.environ.get("GYTDL_COMMAND", "gytdl")
+PYTDL_COMMAND = os.environ.get("PYTDL_COMMAND", "pytdl")
+GPYTDL_COMMAND = os.environ.get("GPYTDL_COMMAND", "gpytdl")
 RCLONE_CONFIG = os.environ.get("RCLONE_CONFIG", "")
 DESTINATION_FOLDER = os.environ.get("DESTINATION_FOLDER", "")
 INDEX_LINK = os.environ.get("INDEX_LINK", "")
-TELEGRAM_LEECH_COMMAND = os.environ.get("TELEGRAM_LEECH_COMMAND", "tgfile_leech")
-TELEGRAM_LEECH_UNZIP_COMMAND = os.environ.get(
-    "TELEGRAM_LEECH_UNZIP_COMMAND", "tgfile_extract"
-)
 CANCEL_COMMAND_G = os.environ.get("CANCEL_COMMAND_G", "cancel")
 GET_SIZE_G = os.environ.get("GET_SIZE_G", "getsize")
 STATUS_COMMAND = os.environ.get("STATUS_COMMAND", "status")
-SAVE_THUMBNAIL = os.environ.get("SAVE_THUMBNAIL", "savethumbnail")
-CLEAR_THUMBNAIL = os.environ.get("CLEAR_THUMBNAIL", "clearthumbnail")
+SAVE_THUMBNAIL = os.environ.get("SAVE_THUMBNAIL", "savethumb")
+CLEAR_THUMBNAIL = os.environ.get("CLEAR_THUMBNAIL", "clearthumb")
 UPLOAD_AS_DOC = os.environ.get("UPLOAD_AS_DOC", "False")
-PYTDL_COMMAND = os.environ.get("PYTDL_COMMAND", "pytdl")
-GPYTDL_COMMAND = os.environ.get("GPYTDL_COMMAND", "gpytdl")
 LOG_COMMAND = os.environ.get("LOG_COMMAND", "log")
-CLONE_COMMAND_G = os.environ.get("CLONE_COMMAND_G", "gclone")
 UPLOAD_COMMAND = os.environ.get("UPLOAD_COMMAND", "upload")
 RENEWME_COMMAND = os.environ.get("RENEWME_COMMAND", "renewme")
 RENAME_COMMAND = os.environ.get("RENAME_COMMAND", "rename")
-TOGGLE_VID = os.environ.get("TOGGLE_VID", "upload_vid")
-TOGGLE_DOC = os.environ.get("TOGGLE_DOC", "upload_doc")
+TOGGLE_VID = os.environ.get("TOGGLE_VID", "toggledvid")
+TOGGLE_DOC = os.environ.get("TOGGLE_DOC", "toggledoc")
 BOT_START_TIME = time.time()
 # dict to control uploading and downloading
 gDict = defaultdict(lambda: [])
 # user settings dict #ToDo
 user_settings = defaultdict(lambda: {})
 
+updater = tg.Updater(token=TG_BOT_TOKEN)
+bot = updater.bot
 
 def multi_rclone_init():
-    if RCLONE_CONFIG:
-        LOGGER.info("Found RCLONE_CONFIG in variables")
-    if not os.path.exists("rclone.conf"):
-        LOGGER.info("rclone.conf is not present! ignore if not using rclone")
-        return
-    if not os.path.exists("rclone_bak.conf"):  # backup rclone.conf file
+    if not os.path.exists("rclone.conf") and RCLONE_CONFIG:  # you never know
+        LOGGER.critical("found rclone config in variables, but could not find rclone.conf. Upload rclone.conf to root directory of repo!")
+        exit()
+    if not os.path.exists("rclone_bak.conf") and os.path.exists("rclone.conf"):  # backup rclone.conf file
         with open("rclone_bak.conf", "w+", newline="\n", encoding="utf-8") as fole:
             with open("rclone.conf", "r") as f:
                 fole.write(f.read())
         LOGGER.info("rclone.conf backuped to rclone_bak.conf!")
 
+def bcmds():
+    botcmds = [
+    BotCommand(f'/start','Get Start Msg'),
+    BotCommand(f'/help','Get Detailed Help'),
+    BotCommand(f'{LEECH_COMMAND}','Start Leeching'),
+    BotCommand(f'{LEECH_ZIP_COMMAND}','Archive Leech'),
+    BotCommand(f'{LEECH_UNZIP_COMMAND}','Extract Leech'),
+    BotCommand(f'{GLEECH_COMMAND}','Leech & Upload to Drive'),
+    BotCommand(f'{GLEECH_ZIP_COMMAND}','Leech, Archive, & Upload to Drive'),
+    BotCommand(f'{GLEECH_UNZIP_COMMAND}','Leech, Extract, & Upload to Drive'),
+    BotCommand(f'{CLONE_COMMAND_G}','Clone GDrive Files'),
+    BotCommand(f'{TELEGRAM_LEECH_COMMAND}','Leech Telegram Files & Upload to Drive'),
+    BotCommand(f'{TELEGRAM_LEECH_UNZIP_COMMAND}','Leech Telegram Files, Extract, & Upload to Drive'),
+    BotCommand(f'{CANCEL_COMMAND_G}','Cancel Leech'),
+    BotCommand(f'{YTDL_COMMAND}','Leech YT Videos, & supported Links'),
+    BotCommand(f'{PYTDL_COMMAND}','Leech YT Playlists'),
+    BotCommand(f'{GYTDL_COMMAND}','Leech YT Videos, supported Links, and Upload to Drive'),
+    BotCommand(f'{GPYTDL_COMMAND}','Leech YT Playlists, and Upload to Drive'),
+    BotCommand(f'{STATUS_COMMAND}','Check Status'),
+    BotCommand(f'{SAVE_THUMBNAIL}','Save Image for Thumbnail'),
+    BotCommand(f'{CLEAR_THUMBNAIL}','Clear Saved Thumbnail'),
+    BotCommand(f'{RENAME_COMMAND}','Rename Telegram Files'),
+    BotCommand(f'{RENEWME_COMMAND}','Clear bugged downloads'),
+    BotCommand(f'{TOGGLE_VID}','Upload as a Video'),
+    BotCommand(f'{TOGGLE_DOC}','Upload as a Document'),
+    BotCommand(f'/rclone','Change rclone Config'),
+    BotCommand(f'{GET_SIZE_G}','Start Leeching'),
+    BotCommand(f'{LOG_COMMAND}','Start Leeching')]
+    bot.set_my_commands(botcmds)
+    LOGGER.info("Added Bot CMDS!")
+
 
 multi_rclone_init()
+bcmds()
