@@ -1,6 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 # (c) Shrimadhav U K | gautamajay52
+# modified by reaitten/orsixtyone
 
 import asyncio
 import logging
@@ -330,21 +331,23 @@ async def check_progress_for_dl(aria2, gid, event, previous_message):
                 if is_file is None:
                     msgg = f"<b>Connections: {file.connections} </b>"
                 else:
-                    msgg = f"<b>P: {file.connections}\nS: {file.num_seeders} </b>\n\n<b>GID:</b> <code>{gid}</code>"
+                    msgg = f"<b>P: {file.connections} | S: {file.num_seeders} </b>\n\n<b>GID:</b> <code>{gid}</code>"
                     
                 dnld_complete = convert_size(round(convert_to_bytes(file.total_length_string()) * (float(re.sub("[^0-9.]", "", file.progress_string()))/100),2))
                 percentage = int(file.progress_string(0).split('%')[0])
                 prog = "[{0}{1}]".format("".join([FINISHED_PROGRESS_STR for i in range(math.floor(percentage / 5))]),"".join([UN_FINISHED_PROGRESS_STR for i in range(20 - math.floor(percentage / 5))]))
                 
-                msg = f"\n<b>File name:</b> `{downloading_dir_name}`\n\n<b>Speed:</b> `{file.download_speed_string()}`"
-                msg += f"\n<b>Size:</b> `{file.total_length_string()}`"
-                msg += f"\n<b>{prog}</b>"
-                msg += f"\n<b>Downloaded</b>: `{dnld_complete} of {file.progress_string()}` \n<b>ETA:</b> `{file.eta_string()}` \n {msgg}"
+                msg = f"\n<b>Filename:</b> `{downloading_dir_name}`\n\n"
+                msg += f"\n<b>{prog}</b> `{file.progress_string()}`"
+                msg += f"\n<b>Downloaded</b>: `{dnld_complete} of {file.total_length_string()}`"
+                msg += f"\n<b>Speed:</b> `{file.download_speed_string()}`"
+                msg += f"\n<b>ETA:</b> `{file.eta_string()}`"
+                msg += f"\n\n{msgg}"
                 inline_keyboard = []
                 ikeyboard = []
                 ikeyboard.append(
                     InlineKeyboardButton(
-                        "Cancel", callback_data=(f"cancel {gid}").encode("UTF-8")
+                        "Cancel.", callback_data=(f"cancel {gid}").encode("UTF-8")
                     )
                 )
                 inline_keyboard.append(ikeyboard)
