@@ -1,6 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 # (c) Shrimadhav U K | gautamajay52
+# modified by reaitten/orsixtyone
 
 import asyncio
 import logging
@@ -132,7 +133,7 @@ async def incoming_youtube_dl_f(client, message):
         #f"<b>⚙ Leeching For :</b> {u_men}",
         #parse_mode="html",
     #)
-    i_m_sefg = await message.reply_text("<code>Prrocessing..</code>", quote=True)
+    i_m_sefg = await message.reply_text("<code>Processing..</code>", quote=True)
     # LOGGER.info(message)
     # extract link from message
     if message.reply_to_message:
@@ -200,7 +201,7 @@ async def g_yt_playlist(client, message):
         if user_command == GPYTDL_COMMAND.lower():
             is_cloud = True
     else:
-        await message.reply_text("<b> Reply with Playlist link</b>", quote=True)
+        await message.reply_text("<b>Reply with Playlist link</b>", quote=True)
         return
     if "youtube.com/playlist" in url:
         u_men = message.from_user.mention
